@@ -1,9 +1,6 @@
 use anyhow::Result;
 use clap::ArgMatches;
-use prs_lib::{
-    crypto::{self, prelude::*},
-    Store,
-};
+use prs_lib::{crypto::prelude::*, Store};
 use thiserror::Error;
 
 use crate::cmd::matcher::{copy::CopyMatcher, MainMatcher, Matcher};
@@ -45,7 +42,7 @@ impl<'a> Copy<'a> {
 
         secret::print_name(matcher_copy.query(), &secret, &store, matcher_main.quiet());
 
-        let mut plaintext = crypto::context(crypto::PROTO)?
+        let mut plaintext = crate::crypto::context(&matcher_main)?
             .decrypt_file(&secret.path)
             .map_err(Err::Read)?;
 
