@@ -6,7 +6,9 @@ use prs_lib::{store::SecretIterConfig, Secret, Store};
 use text_trees::{FormatCharacters, StringTreeNode, TreeFormatting};
 use thiserror::Error;
 
-use crate::cmd::matcher::{list::ListMatcher, MainMatcher, Matcher};
+#[cfg(all(feature = "tomb", target_os = "linux"))]
+use crate::cmd::matcher::MainMatcher;
+use crate::cmd::matcher::{list::ListMatcher, Matcher};
 #[cfg(all(feature = "tomb", target_os = "linux"))]
 use crate::util::tomb;
 
@@ -24,6 +26,7 @@ impl<'a> List<'a> {
     /// Invoke the list action.
     pub fn invoke(&self) -> Result<()> {
         // Create the command matchers
+        #[cfg(all(feature = "tomb", target_os = "linux"))]
         let matcher_main = MainMatcher::with(self.cmd_matches).unwrap();
         let matcher_list = ListMatcher::with(self.cmd_matches).unwrap();
 
