@@ -36,6 +36,12 @@ impl CmdGenerate {
                         "Generated password length in characters. Passphrase length in words.",
                     ),
             )
+            .arg(
+                Arg::new("merge")
+                    .long("merge")
+                    .short('m')
+                    .about("Merge into existing secret, don't create new secret"),
+            )
             .arg(
                 Arg::new("edit")
                     .long("edit")
